--爬塔布阵
checkRequire("Lua_FightLineupWindow")
Lua_TowerLineupWindow = class("Lua_TowerLineupWindow", Lua_FightLineupWindow);
function Lua_TowerLineupWindow:ctor()
    self:superCall("ctor");
    self.windowName = "Lua_TowerLineupWindow";
end

function Lua_TowerLineupWindow:buildShowItem()
    self:superCall("buildShowItem");
    self:addLuaEvent("TOWER_LINEUP_HERO_SELECT", self, self.onHeroSelected); -- 选择英雄

    self.heroList:setListCell(Lua_TowerLineupCell, 107, 107, 5);
end

function Lua_TowerLineupWindow:dispose()
    self.campLimitDic = nil;
    self.des = nil;
    self:superCall("dispose");
end

function Lua_TowerLineupWindow:updateShowInfo(param)
    -- param.limit_camp; --上阵类型限制
    -- param.id; -- 爬塔类型
    self.stage_id = param.cur_stage_id; -- 关卡id
    self.template_id = param.fight_id; -- 战斗模板id
    self.lineup_type = Lua_FightTemplateConfigData.getConfigData(self.template_id).lineup_type;

    local config = DataCenter.climbTowerUtil:getTowerConfig(self.stage_id);--关卡数据
    self.monster_player_id = config.robot
    self.limit_num = config.limit_num; --最大上阵数量

    self.campLimitDic = {}
    local obj;
    for i = 1, #param.limit_camp do
        obj = param.limit_camp[i];
        self.campLimitDic[obj] = 1;
    end
    self.campLimitTips = LanUtil.formateStr(201025, DataCenter.climbTowerUtil:limitCampName(param.limit_camp));

    self:showSceneByTemplateId(self.template_id);
    self:updateLineupInfo();
    self:updateEnemyInfo();
    self.campSiftPanel:setLimitCamp(self.campLimitDic, self.campLimitTips);
    self.campSiftPanel:setSelected(Lua_HeroUtil.All_TYPE, 0);
    self:updatePrompt();

    if param.new_step > 0 and param.cur_stage_id >= param.new_step then
        self:createTeamButton(self.data.team_number)
    end
end

function Lua_TowerLineupWindow:updateLineupNum()
    self:superCall("updateLineupNum");
    self:updatePrompt();
end

-- 更新条件描述
function Lua_TowerLineupWindow:updatePrompt()
    if self.showData.camp == 0 then
        return
    end

    if self.checkHelp == nil then
        self.checkHelp = UICreate.createUIAtlasImage(self.topObject, "common_altas_1", "ui_common_button_016_n", -320, -215, 0, 0);
    end

    if self.promptText == nil then
        self.promptText = UICreate.createLabel(self.topObject, LanUtil.getValue(126322), -235, -215, 100, 31, 22);
        self.promptText.alignmentValue = 3;
        self.promptText.horizontalOverflowValue = 1;
    end

    self.promptText.text = LanUtil.formateStr(201024, tostring(self.limit_num), DataCenter.climbTowerUtil:limitCampName(self.showData.limit_camp));
    local num = self.data:getHeroNumByLineupIdx(self.lineupIdx)
    if num < self.limit_num then
        self.promptText.colorStr = Lua_ColorDefine.transColorStr("F63C3C")
    else
        self.promptText.colorStr = Lua_ColorDefine.transColorStr("59CD20")
    end
end

-- 更新筛选状态
function Lua_TowerLineupWindow:onCampSelected(campType, careerType)
    if campType ~= 0 and self.campLimitDic[campType] == nil then
        OperateAlert.show(self.campLimitTips);
        return;
    end
    
    self:superCall("onCampSelected", campType, careerType);
end

function Lua_TowerLineupWindow:updateHeroList()
    local arr = DataCenter.heroLineupData:getHeroListByCampDic(self.selectedCampType, self.selectedCareer, self.campLimitDic, self.lineup_type, self.lineupIdx);
    self.heroList.customParam = self.lineup_type * 10000 + self.lineupIdx * 100 + self.showData.id;
    self.heroList:setArrayData(arr);
    self.heroList:moveToIndex(1);
    self:showNone(arr:getSize() <= 0);
end

--选择英雄
function Lua_TowerLineupWindow:onHeroSelected(heroVo)
    local standIdx = self.data:getHeroStandIdx(heroVo.unique_id)
    if standIdx == nil then -- 未上阵
        standIdx = DataCenter.heroLineupData:getNullStandIdx(self.stand_type, self.localLineupDic, self.lineupIdx)
        if standIdx == nil then -- 上阵英雄已达上限
            OperateAlert.showLangValue(126300)
            return
        end

        local num = 0
        local arr = self.localLineupDic[self.lineupIdx]
        for i = 1, arr:getSize() do
            if arr[i] > 0 then
                num = num + 1
            end
        end
        if num == self.limit_num then --上阵英雄已达上限
            OperateAlert.showLangValue(126300);
            return
        end

        local lineupIdx = self.data:getHeroLineupIdx(heroVo.id)
        if lineupIdx then
            if lineupIdx == self.lineupIdx then
                OperateAlert.showLangValue(126302)
            else
                OperateAlert.show(LanUtil.formateStr(126325, convert_arab_to_chinese(lineupIdx)))
            end
            return
        end

        local trialLineupLimit = nil; -- 试用英雄上阵限制
        local trialTowerLimit = nil; -- 试用英雄爬塔次数限制
        if heroVo.trial_state then
            trialLineupLimit = DataCenter.heroUtil:trialHeroLineup(self.lineup_type);
            trialTowerLimit = DataCenter.heroData:isClimbLimit(heroVo.unique_id, self.showData.id);
        end
        
        if trialLineupLimit == true then
            if trialTowerLimit == false then
                OperateAlert.show(LanUtil.formateStr(201017, heroVo.name));
                return;
            elseif trialTowerLimit == true then
                local towerType = self.showData.id;
                local towerVo = DataCenter.climbTowerData:getTowerVoById(towerType);
                local count = DataCenter.heroData:getTrialTowerCount(heroVo.unique_id, towerType);
                local num = DataCenter.heroUtil:trialTowerlimit(towerType);
                OperateAlert.show(LanUtil.formateStr(201018, heroVo.name, towerVo.name, count, num));
            end
        end

        self.localLineupDic[self.lineupIdx][standIdx] = heroVo.unique_id
    else
        self.localLineupDic[self.lineupIdx][standIdx] = 0
    end

    self:updateHeroSelected();
    self:updateSceneModel();
    self:updateLineupNum();
    self:updateAureoleInfo();
end

--一键上阵
function Lua_TowerLineupWindow:onOneBtnClick(go)
    local arr = DataCenter.heroLineupData:getHeroListByCampDic(0, 0, self.campLimitDic, self.lineup_type, self.lineupIdx, 1);
    DataCenter.heroLineupData:setHeroOneKey(self.stand_type, self.localLineupDic, self.lineupIdx, self.lineup_type, arr, self.limit_num);

    self:updateHeroSelected();
    self:updateSceneModel();
    self:updateLineupNum();
    self:updateAureoleInfo();
end

function Lua_TowerLineupWindow:onCheckLineup()
    local num
    if self.lineupArr == nil then
        num = self.data:getHeroNumByLineupIdx(self.lineupIdx)
        if num == 0 then
            OperateAlert.showLangValue(126307);
            return
        end
        if num < self.limit_num then
            local arr = DataCenter.heroLineupData:getHeroListByCampDic(0, 0, self.campLimitDic, self.lineup_type, self.lineupIdx, 1);
            if DataCenter.heroLineupData:checkPackHaveHero(self.localLineupDic, arr) then
                local tipsData = { des = 126312, btnType = 1, cancelLabel = 126328, owner = self, sureFun = self.onStartFight }
                Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData)
                return
            end
        end
        if self.showData.camp > 0 then
            local arr = self.localLineupDic[self.lineupIdx];
            local campType;
            for i = 1, arr:getSize() do
                if arr[i] > 0 then
                    campType = DataCenter.heroData:getItemByUniqueId(arr[i]).campType;
                    if self.campLimitDic[campType] == nil then
                        OperateAlert.showLangValue(201019);
                        return;
                    end
                end
            end
        end
    else
        for i = 1, self.data.team_number do
            num = self.data:getHeroNumByLineupIdx(i)
            if num == 0 then
                OperateAlert.show(LanUtil.formateStr(126326, convert_arab_to_chinese(i)));
                return
            end
        end
        for i = 1, self.data.team_number do
            num = self.data:getHeroNumByLineupIdx(i)
            if num < self.limit_num then
                local arr = DataCenter.heroLineupData:getHeroListByCampDic(0, 0, self.campLimitDic, self.lineup_type, i, 1);
                if DataCenter.heroLineupData:checkPackHaveHero(self.localLineupDic, arr) then
                    local tipsData = { des = 126312, btnType = 1, cancelLabel = 126328, owner = self, sureFun = self.onStartFight }
                    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData)
                    return
                end
            end
        end
        if self.showData.camp > 0 then
            for i = 1, self.data.team_number do
                local arr = self.localLineupDic[i];
                local campType;
                for j = 1, arr:getSize() do
                    if arr[j] > 0 then
                        campType = DataCenter.heroData:getItemByUniqueId(arr[j]).campType;
                        if self.campLimitDic[campType] == nil then
                            OperateAlert.showLangValue(201019);
                            return;
                        end
                    end
                end
            end
        end
    end

    self:onStartFight();
end

























Lua_TowerLineupCell = class("Lua_TowerLineupCell", Lua_HeroLineupCell);

function Lua_TowerLineupCell:setCustomParam(customParam)
    self.customParam = customParam;
    self.curLineupType = Mathf.Floor(customParam / 10000);
    self.curLineupIdx = Mathf.Floor(customParam / 100 % 10);
    self.curTowerId = customParam % 10;
end

function Lua_TowerLineupCell:setData(data)
    self.data = DataCenter.heroData:getItemByUniqueId(data);
    self.itemIcon:setData(self.data);

    self.trialLineupLimit = nil; -- 试用英雄上阵限制
    self.trialTowerLimit = nil; -- 试用英雄爬塔次数限制
    if self.data.trial_state then
        self.trialLineupLimit = DataCenter.heroUtil:trialHeroLineup(self.curLineupType);
        self.trialTowerLimit = DataCenter.heroData:isClimbLimit(self.data.unique_id, self.curTowerId);
    end

    self.itemIcon:setLock(self.trialLineupLimit == false or (self.trialLineupLimit == true and self.trialTowerLimit == false));
    self:updateSelected();
end

function Lua_TowerLineupCell:onPressClick()
    if self.trialLineupLimit == false then
        OperateAlert.show(LanUtil.formateStr(201020, self.data.name));
        return;
    end

    if self.lineupIdx and self.lineupIdx ~= self.curLineupIdx then
        OperateAlert.show(LanUtil.formateStr(126325, convert_arab_to_chinese(self.lineupIdx)))
        return
    end

    Lua_MsgUtil.callFunc("TOWER_LINEUP_HERO_SELECT", self.data);
end
